@@ -3,18 +3,19 @@ Defines the base class for all choosers in LSR.
 
 @author: Peter Parente
 @organization: IBM Corporation
-@copyright: Copyright (c) 2005, 2006 IBM Corporation
-@license: Common Public License 1.0
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 import weakref, os.path
 import AEEvent, UIElement
 
-SINGLETONS = weakref.WeakValueDictionary()
+GLOBAL_SINGLETONS = weakref.WeakValueDictionary()
+APP_SINGLETONS = {}
 
 class AEChooser(UIElement.UIE):
   '''  
@@ -23,10 +24,15 @@ class AEChooser(UIElement.UIE):
   This class is abstract as most of its methods raise NotImplementedError and 
   need to be overriden in subclasses.
   
-  @cvar SINGLETON: Should only one instance of this chooser live at a time? 
-    This flag should be overriden by a subclass to indicate whether the
-    chooser is a singleton or not.
-  @type SINGLETON: boolean
+  @cvar GLOBAL_SINGLETON: Allow only one instance of a chooser to exist at a
+    time globally? This flag should be overriden by a subclass to indicate
+    whether the chooser is a global singleton or not.
+  @type GLOBAL_SINGLETON: boolean
+  @cvar APP_SINGLETON: Allow only one instance of a chooser to exist at a 
+    time for a given application? This flag should be overriden by a subclass 
+    to indicate whether the chooser is an application singleton or not.
+    Meaningless if L{GLOBAL_SINGLETON} is set.
+  @type APP_SINGLETON: boolean
   @cvar OK: Indicates the chooser is completing and its options should be
     applied
   @type OK: integer
@@ -47,7 +53,8 @@ class AEChooser(UIElement.UIE):
     method after a L{OK} or L{CANCEL} signal is sent
   @type block_signals: boolean
   '''
-  SINGLETON = False
+  GLOBAL_SINGLETON = False
+  APP_SINGLETON = False
   # these must be mutually exclusive from the signal constants used by subclass
   CANCEL = -1000
   APPLY = -1001
@@ -75,18 +82,31 @@ class AEChooser(UIElement.UIE):
     @param aid: Unique identifier for the application L{Tier} with which the 
       L{AEChooser} that fired this event is associated
     @type aid: L{Tier}
-    @raise ValueError: When the L{SINGLETON} flag is set to True and a 
-      singleton already exists
+    @raise ValueError: When the L{GLOBAL_SINGLETON} flag is set to True and a 
+      singleton already exists or L{APP_SINGLETON} flag is set to True and a
+      chooser for the application already exists.
     '''
     cls = self.getClassName()
-    if self.SINGLETON and cls in SINGLETONS:
-      raise ValueError(SINGLETONS[cls])
+    
+    if self.GLOBAL_SINGLETON and cls in GLOBAL_SINGLETONS:
+      raise ValueError(GLOBAL_SINGLETONS[cls])
+    elif (self.APP_SINGLETON and 
+          APP_SINGLETONS.has_key(cls) and 
+          aid in APP_SINGLETONS[cls]):
+      raise ValueError(APP_SINGLETONS[cls][aid])
+    
     self.aid = aid
     self.event_man = event_man
     # store a weakref for singletons
-    if self.SINGLETON:
-      SINGLETONS[cls] = self
-  
+    if self.GLOBAL_SINGLETON:
+      GLOBAL_SINGLETONS[cls] = self
+    # store a WeakValueDictionary
+    elif self.APP_SINGLETON:
+      try:
+        APP_SINGLETONS[cls][aid] = self
+      except KeyError:
+        APP_SINGLETONS[cls] = weakref.WeakValueDictionary({aid:self})
+          
   def init(self, **kwargs):
     '''
     Initializes the chooser. Should enable the chooser for interaction with the
@@ -135,15 +155,17 @@ class AEChooser(UIElement.UIE):
     @rtype: string
     '''
     return os.path.join(self.getPath(), name)
-  
+
   def _signal(self, kind, **kwargs):
-    '''    
-    Posts an L{AEEvent.ChooserChange} event to the L{EventManager}. The kind of
-    change should be any arbitrary string or one of L{OK}, L{APPLY}, L{CANCEL}.
-    Any keyword arguments will be delivered to an observer. The event will also
-    include a reference to this L{AEChooser} such that an observer can call the
-    L{update} method on it. After one cancel or one OK signal is propogated,
-    no more signals are allowed to be sent.
+    '''        
+    Posts an L{AEEvent.ChooserChange} event to the L{EventManager}. Chooser
+    change events should have an arbitrary kind or one of the special L{OK},
+    L{APPLY}, L{CANCEL} valus. Any keyword arguments will be delivered to the
+    observer. The event will also include a reference to this L{AEChooser} such
+    that an observer can call the L{update} method on it. The event is 
+    delivered only to the L{Perk} responsible for managing this chooser.
+    
+    After one cancel or one OK signal is fired, no more signals are sent.
     
     @param kind: Kind of signal, one of L{OK}, L{APPLY}, L{CANCEL} or a chooser
       defined integer constant
