@@ -4,17 +4,53 @@ Defines the base class for all L{AccessEngine} events (L{AEEvent}s).
 @author: Peter Parente
 @author: Pete Brunet
 @organization: IBM Corporation
-@copyright: Copyright (c) 2005, 2006 IBM Corporation
-@license: Common Public License 1.0
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
+import AEConstants
+from AEInterfaces import *
 
-from LSRInterfaces import *
-import Constants
+default_types = []
+all_types = []
+
+def registerEventType(name, default):
+  '''
+  Called once by every L{AEEvent} class to register itself for buffering and 
+  filtering by an L{AEMonitor}.
+  
+  @param name: Name of the L{AEEvent}
+  @type name: string
+  @param default: Should this L{AEEvent} be buffered by default?
+  @type default: boolean
+  '''
+  global default_types
+  global all_types
+  all_types.append(name)
+  if default:
+    default_types.append(name)
+    
+def getDefaults():
+  '''
+  Suggests the default L{AEEvent}s to be monitored.
+  
+  @return: Names of defaults to monitor
+  @rtype: list of string
+  '''
+  return default_types  
+  
+def getNames():
+  '''
+  Gets the names of all the L{AEEvent} types.
+  
+  @return: List of all L{AEEvent} names
+  @rtype: list of string
+  '''
+  return all_types
 
 class AccessEngineEvent(object):
   '''
@@ -29,11 +65,11 @@ class AccessEngineEvent(object):
   @ivar por: Point of regard associated with this event
   @type por: L{POR}
   '''
-  def __init__(self, priority=Constants.NORMAL, focused=False):
+  def __init__(self, priority=AEConstants.EXEC_NORMAL, focused=False,**kwargs):
     '''
     Stores the event priority and whether the event source was focused or not.
 
-    @param priority: Priority of this event, defaults to L{Constants.NORMAL}
+    @param priority: Priority of this event, defaults to normal
     @type priority: integer    
     @param focused: Was the source of the event focused at the time of event 
       creation?
@@ -42,9 +78,9 @@ class AccessEngineEvent(object):
     self.priority = priority
     self.por = None
     if focused:
-      self.layer = Constants.FOCUS_LAYER
+      self.layer = AEConstants.LAYER_FOCUS
     else:
-      self.layer = Constants.BACKGROUND_LAYER
+      self.layer = AEConstants.LAYER_BACKGROUND
     
   def __str__(self):
     '''
@@ -53,12 +89,7 @@ class AccessEngineEvent(object):
     @return: Class name of this AEEvent
     @rtype: string
     '''
-    if self.layer == Constants.FOCUS_LAYER:
-      level = 'focus'
-    elif self.layer == Constants.TIER_LAYER:
-      level = 'tier'
-    else:
-      level = 'background'
+    level = AEConstants.LAYER_NAMES[self.layer]
     return '%s (%s)' % (self.__class__.__name__, level)
     
   def execute(self, **kwargs):
@@ -109,7 +140,7 @@ class AccessEngineEvent(object):
     '''
     if self.por is not None and self.por.incomplete:
       if IAccessibleInfo(self.getPOR()).hasAccState('focused'):
-        self.layer = Constants.FOCUS_LAYER
+        self.layer = AEConstants.LAYER_FOCUS
     return self.layer
 
   def getDataForTask(self):
@@ -119,11 +150,19 @@ class AccessEngineEvent(object):
     L{TierManager.TierManager.manageEvent} or
     L{TierManager.TierManager.manageGesture}.
     
-    @return: Dictionary of parameters to be passed to a L{Task}.
+    @return: Empty dictionary
     @rtype: dictionary
-    @raise NotImplementedError: When not overridden in a subclass
     '''
-    raise NotImplementedError
+    return {}
+  
+  def getTimestamp(self):
+    '''
+    Gets the timestamp for when the event occurred.
+    
+    @return: Always zero when not overridden
+    @rtype: float
+    '''
+    return 0
   
   def getPOR(self):
     '''
@@ -143,4 +182,8 @@ class AccessEngineEvent(object):
     if self.por is None:
       return None
     else:
-      return IAccessibleInfo(self.por).getAccAppID()
+      try:
+        return IAccessibleInfo(self.por).getAccAppID()
+      except LookupError:
+        # app is dead
+        return None
