@@ -3,48 +3,37 @@ Defines an L{AEEvent} indicating that the selector has moved.
 
 @author: Pete Brunet
 @organization: IBM Corporation
-@copyright: Copyright (c) 2005, 2006 IBM Corporation
-@license: Common Public License 1.0
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
-import Base, Constants
+import Base
 
 class ScreenChange(Base.AccessEngineEvent):
   '''
   Event that fires when some aspect of screen bounds or visible data changes.
   
   This class registers its name and whether it should be monitored by default in
-  an L{AEMonitor} using the L{Constants.registerEventType} function
+  an L{AEMonitor} using the L{Base.registerEventType} function
   when this module is first imported. The L{AEMonitor} can use this
   information to build its menus.
   
-  @cvar TEXT_BOUNDS: Bounds on a body of text changed
-  @type TEXT_BOUNDS: integer
-  @cvar VISIBLE_DATA: Visible data on the screen changed in some manner
-  @type VISIBLE_DATA: integer
-  @cvar OBJECT_BOUNDS: Bounds on an object changed
-  @type OBJECT_BOUNDS: integer
   @ivar kind: One of the integer class variables in this class
   @type kind: integer
   '''
-  OBJECT_BOUNDS = 0
-  VISIBLE_DATA = 1 
-  TEXT_BOUNDS = 2
-  
-  Constants.registerEventType('ScreenChange', False)
+  Base.registerEventType('ScreenChange', False)
   def __init__(self, por, kind, **kwargs):
     '''
     Calls the base class and stores L{POR} and type of event.
     
     @param por: Point of regard to an object that changed on screen
     @type por: L{POR}
-    @param kind: Kind of screen change event, one of  L{OBJECT_BOUNDS}, 
-      L{VISIBLE_DATA}, or L{TEXT_BOUNDS}
+    @param kind: Kind of screen change event
     @type kind: integer
     '''
     Base.AccessEngineEvent.__init__(self, **kwargs)
@@ -60,9 +49,9 @@ class ScreenChange(Base.AccessEngineEvent):
     @rtype: string
     '''
     name = Base.AccessEngineEvent.__str__(self)
-    if self.kind == self.OBJECT_BOUNDS:
+    if self.kind == AEConstants.EVENT_OBJECT_BOUNDS:
       action = 'object bounds'
-    elif self.kind == self.TEXT_BOUNDS:
+    elif self.kind == AEConstants.EVENT_TEXT_BOUNDS:
       action = 'text bounds'
     else:
       action = 'visible data'
