@@ -6,13 +6,13 @@ subtree of the hierarchy, a single kind of exception, or all exceptions.
 
 @author: Peter Parente
 @organization: IBM Corporation
-@copyright: Copyright (c) 2006 IBM Corporation
-@license: Common Public License 1.0
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
 from i18n import _
@@ -30,4 +30,4 @@ class InitError(AEInputError):
   '''
   def __init__(self, *args, **kwargs):
     AEOutputError.__init__(self,
-      _('The input device could not be initialized'), *args, **kwargs)
\ No newline at end of file
+      _('could not initialize input device'), *args, **kwargs)
\ No newline at end of file
