@@ -5,13 +5,13 @@ command, camera tracked gesture, etc.) performed simultaneously.
 
 @author: Peter Parente
 @organization: IBM Corporation
-@copyright: Copyright (c) 2005, 2006 IBM Corporation
-@license: Common Public License 1.0
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
 class Gesture(object):
@@ -156,7 +156,7 @@ class Gesture(object):
     @param code: Action code to add to this L{Gesture}
     @type code: integer
     @raise ValueError: When the L{Gesture} is full according to 
-      L{AEInput.AEInput.getMaxActions}
+      L{AEInput.Base.AEInput.getMaxActions}
     '''
     # check if full
     if len(self.action_codes) == self.device.getMaxActions():
@@ -228,7 +228,8 @@ class Gesture(object):
     '''
     Gets the number of action codes stored in this L{Gesture}.
     
-    @return: Number of action codes bounded by L{AEInput.AEInput.getMaxActions}
+    @return: Number of action codes bounded by
+    L{AEInput.Base.AEInput.getMaxActions}
     @rtype: integer
     '''
     return len(self.action_codes)
@@ -241,4 +242,4 @@ class Gesture(object):
     @return: Text representation of the actions in this L{Gesture}
     @rtype: string
     '''
-    return self.device.asString(self)
\ No newline at end of file
+    return self.device.asString(self)
