@@ -14,7 +14,7 @@ U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 import logging
 import Base
-from LSRInterfaces import implements
+from AEInterfaces import implements
 
 log = logging.getLogger('Monitor')
 
