@@ -199,7 +199,7 @@ class AEOutput(UIElement.UIE):
     The total number of requested styles (num_groups * num_layers) must be
     returned. If the device cannot honor the request for the number of distinct
     styles it is asked to generate, it may duplicate styles it has already
-    created using L{AEState.AEState.copy} to fulfill the quota.
+    created using L{AEState.Base.AEState.copy} to fulfill the quota.
     
     The device is B{not} expected to create distinct styles across invocations 
     of this method. This method should only be called once by L{DeviceManager}
@@ -272,8 +272,8 @@ class AEOutput(UIElement.UIE):
     
     This is a generic method which receives all content and commands to be 
     rendered and executed on a device. Standard name identifiers should be 
-    used whenever possible. For instance, L{AEConstants.CMD_STOP} and
-    L{AEConstants.CMD_TALK}. However, device specific names and values
+    used whenever possible. For instance, L{AEConstants.Output.CMD_STOP} and
+    L{AEConstants.Output.CMD_TALK}. However, device specific names and values
     are certainly possible.
     
     @param name: Descriptor of the data value sent
