@@ -30,8 +30,6 @@ class Braille(Base.AEOutput):
     Looks at the L{USE_THREAD} flag to see if the device implementing this 
     interface wants a thread proxy or not.
     
-    @todo: PP: proxy not available yet, fails if USE_THREAD is True
-    
     @return: self or L{ThreadProxy.BrailleThreadProxy}
     @rtype: L{AEOutput}
     '''
@@ -42,7 +40,7 @@ class Braille(Base.AEOutput):
     else:
       raise NotImplementedError('USE_THREAD not specified')
 
-  def parseString(self, text, style, por):
+  def parseString(self, text, style, por, sem):
     '''
     Dummy implementation returns the text as-is.
 
@@ -53,6 +51,8 @@ class Braille(Base.AEOutput):
     @param por: Point of regard for the first character in the text, or None if
       the text is not associated with a POR
     @type por: L{POR}
+    @param sem: Semantic tag for the text
+    @type sem: integer
     @return: Parsed words
     @rtype: 3-tuple of lists of string, L{POR}, L{AEOutput.Style}
     '''
