@@ -293,7 +293,7 @@ class AEState(object):
     @param persist: Persist the setting value to disk?
     @type persist: boolean
     @return: New setting object
-    @rtype: L{PercentSetting}
+    @rtype: L{PercentRangeSetting}
     '''
     s = PercentRangeSetting(self, name, default, label, description, persist, 
                             min, max, precision)
@@ -412,12 +412,12 @@ class AEState(object):
                            (self.__class__.__name__, name))
 
   def save(self):
-    '''Invokes L{Setting.save} on all settings in the state.'''
+    '''Invokes L{Setting.Setting.save} on all settings in the state.'''
     for sett in self.settings.values():
       sett.save()
       
   def restore(self):
-    '''Invokes L{Setting.restore} on all settings in the state.'''
+    '''Invokes L{Setting.Setting.restore} on all settings in the state.'''
     for sett in self.settings.values():
       sett.restore()
       
