@@ -16,7 +16,7 @@ import pyLinAcc
 from DefaultInfo import *
 from DefaultNav import *
 from DefaultAction import *
-from LSRInterfaces import *
+from AEInterfaces import *
 from pyLinAcc import Interfaces, Constants
 
 class ContainerAccInfoAdapter(DefaultAccInfoAdapter):
