@@ -1,6 +1,6 @@
 '''
-Defines default L{AccAdapt.Adapter}s for the L{LSRInterfaces.IAccessibleNav} and
-L{LSRInterfaces.IItemNav} interfaces on L{POR.POR} objects.
+Defines default L{AccAdapt.Adapter}s for the L{AEInterfaces.IAccessibleNav} and
+L{AEInterfaces.IItemNav} interfaces on L{POR.POR} objects.
 
 @author: Peter Parente
 @organization: IBM Corporation
@@ -14,7 +14,7 @@ U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 from POR import POR
 from AccAdapt import PORAdapter
-from LSRInterfaces import *
+from AEInterfaces import *
 from pyLinAcc import Interfaces
 import pyLinAcc
 
@@ -230,7 +230,7 @@ class DefaultNavAdapter(PORAdapter):
         por = IPORFactory(acc).create()
         return predicate(por)
       return False
-    acc = self.accessible.findDescendant(por_predicate)
+    acc = self.accessible.findDescendant(por_predicate, not depth_first)
     if acc is not None:
       acc = IPORFactory(acc).create()
     return acc
