@@ -1,5 +1,5 @@
 '''
-Defines an L{AccAdapt.Adapter}s for the L{LSRInterfaces.IAccessibleInfo} 
+Defines an L{AccAdapt.Adapter}s for the L{AEInterfaces.IAccessibleInfo} 
 interface to correct for the problem of pop-up items (e.g menus) always having
 states visible and showing after having been activated once. 
 
@@ -16,7 +16,7 @@ U{http://www.opensource.org/licenses/bsd-license.php}
 
 from DefaultInfo import *
 from DefaultEventHandler import *
-from LSRInterfaces import *
+from AEInterfaces import *
 from pyLinAcc import Constants, Interfaces
 import pyLinAcc
 
