@@ -17,7 +17,7 @@ U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 from POR import POR
 from AEEvent import *
-from LSRInterfaces import *
+from AEInterfaces import *
 from DefaultInfo import DefaultAccInfoAdapter
 from DefaultNav import *
 from DefaultEventHandler import DefaultEventHandlerAdapter
@@ -452,14 +452,15 @@ class SimpleTextEventHandlerAdapter(DefaultEventHandlerAdapter):
     # and the last character is not a newline, correct by going back one 
     # character offset and asking for the line; done to correct problems in
     # single line entry fields in FF
+    qo = caret_offset
     if (caret_offset > 0 and 
         caret_offset >= text.characterCount and
         text.getText(caret_offset-1, -1) != '\n'):
-      caret_offset -= 1
+      qo -= 1
       
-    # get the text of the new caret line, it's starting and ending offsets
+    # get the text of the new caret line, its starting and ending offsets
     line, sOff, eOff = \
-      text.getTextAtOffset(caret_offset, Constants.TEXT_BOUNDARY_LINE_START)
+      text.getTextAtOffset(qo, Constants.TEXT_BOUNDARY_LINE_START)
 
     # create a POR with start offset of the line and relative caret offset
     por = POR(self.subject, sOff, caret_offset - sOff)
