@@ -1,6 +1,6 @@
 '''
 Defines L{AccAdapt.Adapter}s for objects in accessibility toolkits to the
-L{AccAdapt.Interface}s declared in L{LSRInterfaces}. Subpackages contain 
+L{AccAdapt.Interface}s declared in L{AEInterfaces}. Subpackages contain 
 adapters on a per toolkit basis. Adapters for toolkits that are not available
 are not imported.
 
