@@ -275,7 +275,7 @@ class SettingsChooser(AEChooser.AEChooser):
   @cvar TO_UNLOAD: Indicates a L{UIElement} is now set to be unloaded
   @type TO_UNLOAD: integer
   ''' 
-  SINGLETON = True
+  GLOBAL_SINGLETON = True
   PERK = 0
   DEVICE = 1
   SYSTEM = 2
@@ -326,7 +326,7 @@ class SettingsChooser(AEChooser.AEChooser):
 
     # get the dialog widget
     self.dialog = source.get_widget('main dialog')
-    self.activate(timestamp)
+    
     
     # get widget references
     self.tips = gtk.Tooltips()
@@ -346,8 +346,7 @@ class SettingsChooser(AEChooser.AEChooser):
     self.perk_tv.set_model(gtk.ListStore(gobject.TYPE_STRING))
     self.perk_tv.set_data('subsection label', perk_label)
     self.perk_tv.set_data('subsection viewport', perk_vp)
-    # @todo: PP: device might be a tree depending on where semantics are listed
-    # in the future
+    
     self.device_tv.set_model(gtk.ListStore(gobject.TYPE_STRING))
     self.device_tv.set_data('subsection label', device_label)
     self.device_tv.set_data('subsection viewport', device_vp)
@@ -361,14 +360,21 @@ class SettingsChooser(AEChooser.AEChooser):
     self._createProfileView(associated, installed)
     self._createSystemSettingsView()
     
-  def activate(self, timestamp, **kwargs):
+    self.activate(timestamp, present=False)
+    
+  def activate(self, timestamp, present=True, **kwargs):
     '''Try to bring the window to the foreground.'''
     try:
       # try to bring the window to the foreground if this feature is supported
       self.dialog.window.set_user_time(timestamp)
     except AttributeError:
       pass
-    self.dialog.present()
+    if present:
+      try:
+        self.dialog.present()
+      except gtk.Warning:
+        # ignore strange gtk warnings that prevent further building of the UI
+        pass
     
   def _createCustomWidget(self, glade, function_name, widget_name, *args):
     '''
@@ -523,11 +529,12 @@ class SettingsChooser(AEChooser.AEChooser):
     @type viewport: gtk.Viewport
     '''
     x, y = widget.translate_coordinates(viewport, 0, 0)
-    w, h = widget.window.get_geometry()[2:4]
+    w, h = widget.size_request()
     vw, vh = viewport.window.get_geometry()[2:4]
+         
     adj = viewport.get_vadjustment()
-    if y+40 > vh:
-      adj.value += (y+40) - vh - 3
+    if y+h > vh:
+      adj.value += (y+h) - vh - 3
     elif y < 0:
       adj.value = max(adj.value + y, adj.lower)
     
