@@ -5,8 +5,9 @@ monitors.
 @author: Larry Weiss
 @author: Peter Parente
 @author: Brett Clippingdale
+@author: Scott Haeger
 @organization: IBM Corporation
-@copyright: Copyright (c) 2005, 2006 IBM Corporation
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
 @license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made
@@ -15,11 +16,10 @@ this distribution, and is available at
 U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 import logging, sys
-import AEOutput, AEInput, AEEvent, AEMonitor, UIRegistrar
-from LSRInterfaces import implements
+import AEConstants, AEOutput, AEInput, AEEvent, AEMonitor, UIRegistrar
+from AEInterfaces import implements
 from UIRegistrar import DEVICE, MONITOR
 from i18n import _
-import LSRConstants
 
 log = logging.getLogger('Device')
 
@@ -46,12 +46,12 @@ class DeviceManager(object):
   @type acc_eng: L{AccessEngine}
   @ivar marks: Maps index markers on devices to 
   @type marks: dictionary
-  @ivar temp_dev: List of L{AEOutput} and L{AEInput} devices last removed in 
+  @ivar temp_devs: List of L{AEOutput} and L{AEInput} devices last removed in 
     L{unloadDevices} and held until the next call of L{loadDevices}. The 
     purpose of this list is to ensure strong references to all devices exist,
     and thus weak references are not destroyed, until the the L{DeviceManager}
     is repopulated with devices.
-  @type temp_dev: list
+  @type temp_devs: list
   '''
   def __init__(self, acc_eng):
     '''
@@ -68,7 +68,7 @@ class DeviceManager(object):
     self.event_manager = None
     self.settings_manager = None
     self.marks = {}
-    self.temp_out = []
+    self.temp_devs = []
 
   def init(self, event_man, sett_man, **kwargs):
     '''
@@ -125,8 +125,6 @@ class DeviceManager(object):
     continue to exist until the L{DeviceManager} has new devices available 
     for I/O.
     
-    @todo: PP: unload input devices too once input device modifiers can be
-      properly saved and restored
     '''
     for d in self.out_devs[:]:
       self.temp_devs.append(d)
@@ -154,8 +152,8 @@ class DeviceManager(object):
     
     This is a generic method which receives all content and commands to be 
     rendered and executed on a device. Standard name identifiers should be 
-    used whenever possible. For instance, L{AEOutput.Constants.CMD_STOP} and
-    L{AEOutput.Constants.CMD_TALK}. However, device specific names and values
+    used whenever possible. For instance, L{AEConstants.Output.CMD_STOP} and
+    L{AEConstants.Output.CMD_TALK}. However, device specific names and values
     are certainly possible.
 
     @param name: Descriptor of the data value sent
@@ -165,8 +163,7 @@ class DeviceManager(object):
     @param sem: The semantic stream on which to send output; defaults to None 
       for the default semantic.
     @type sem: integer
-    @param layer: Layer on which the event occurred, one of 
-      L{Task.LAYER_FOCUS}, L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
+    @param layer: Layer on which the event occurred
     @type layer: integer
     @param dev: Device that should receive the command
     @type dev: L{AEOutput}
@@ -179,13 +176,20 @@ class DeviceManager(object):
     # quit if no device specified
     if dev is None: return
     if sem is None or layer is None:
-      return dev.send(name, value, None)
+      try:
+        return dev.send(name, value, None)
+      except NotImplementedError:
+        return None
     else:
       style = dev.getStyle((sem, layer))
       # respect muting
       if style.Mute: return
       # send the data
-      rv = dev.send(name, value, style)
+      try:
+        rv = dev.send(name, value, style)
+      except NotImplementedError:
+        # no return value when not implemented
+        rv = None
       # mark the style as clean
       style.makeClean()
       return rv
@@ -199,26 +203,25 @@ class DeviceManager(object):
     @param sem: Semantic description of the information to stop None to 
       indicate stopping all output
     @type sem: integer
-    @param layer: Layer on which the event occurred, one of 
-      L{Task.LAYER_FOCUS}, L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
+    @param layer: Layer on which the event occurred
     @type layer: integer
     '''
     # notify monitors
-    self.out_mons.show(OutputEvent(AEOutput.CMD_STOP), dev=dev, sem=sem, 
+    self.out_mons.show(OutputEvent(AEConstants.CMD_STOP), dev=dev, sem=sem, 
                        layer=layer)
     if dev is None: return
     if sem is None and layer is None:
       # send a global stop
-      dev.send(AEOutput.CMD_STOP, None, None)
+      dev.send(AEConstants.CMD_STOP, None, None)
     elif sem is None:
       # find all styles associated with the given layer
       all = set([dev.getStyle((sem, layer)) for sem in
-                 LSRConstants.SEMANTIC_STYLES.keys()])
+                 AEConstants.SEMANTIC_STYLES.keys()])
       for style in all:
-        dev.send(AEOutput.CMD_STOP, None, style)
+        dev.send(AEConstants.CMD_STOP, None, style)
     else:
       style = dev.getStyle((sem, layer))
-      dev.send(AEOutput.CMD_STOP, None, style)
+      dev.send(AEConstants.CMD_STOP, None, style)
 
   def sendTalk(self, dev, sem, layer):
     '''
@@ -229,19 +232,19 @@ class DeviceManager(object):
     @param sem: Semantic information to start outputting or None to indicate 
       that all buffered information should be output
     @type sem: integer
-    @param layer: Layer on which the event occurred, one of L{Task.LAYER_FOCUS},
-      L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
+    @param layer: Layer on which the event occurred
     @type layer: integer
     '''
     # notify monitors
-    self.out_mons.show(OutputEvent(AEOutput.CMD_TALK), dev=dev, sem=sem, 
+    self.out_mons.show(OutputEvent(AEConstants.CMD_TALK), dev=dev, sem=sem, 
                        layer=layer)
     if dev is None: return
     if sem is None:
       style = None
     else:
       style = dev.getStyle((sem, layer))
-    dev.send(AEOutput.CMD_TALK, None, style)
+    # send the command
+    dev.send(AEConstants.CMD_TALK, None, style)
 
   def sendFilename(self, dev, filename, sem, layer):
     '''
@@ -254,8 +257,7 @@ class DeviceManager(object):
     @param sem: Semantic description of the text to send or None to indicate the
       information is void of any known semantic
     @type sem: integer 
-    @param layer: Layer on which the event occurred, one of L{Task.LAYER_FOCUS},
-      L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
+    @param layer: Layer on which the event occurred
     @type layer: integer
     '''
     # notify monitors
@@ -267,17 +269,15 @@ class DeviceManager(object):
     # respect muting
     if style.Mute: return
     try:
-      dev.send(AEOutput.CMD_FILENAME, filename, style)
+      dev.send(AEConstants.CMD_FILENAME, filename, style)
     except NotImplementedError:
       pass
-    # make the style as clean
+    # make the style clean
     style.makeClean()
     
   def sendString(self, dev, text, sem, layer, por=None):
     '''
     Sends the string to the specified output device.
-    
-    @todo: PP: send indices and collect word markers
 
     @param dev: Device that should receive the command
     @type dev: L{AEOutput}
@@ -286,28 +286,28 @@ class DeviceManager(object):
     @param sem: Semantic description of the text to send or None to indicate 
       the information is void of any known semantic
     @type sem: integer 
-    @param layer: Layer on which the event occurred, one of 
-      L{Task.LAYER_FOCUS}, L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
+    @param layer: Layer on which the event occurred
     @type layer: integer
     @param por: Point of regard to the start of the string if one exists or 
       None if the string did not originate from a L{POR}
     @type por: L{POR}
     '''
     # notify monitors
-    self.out_mons.show(OutputEvent(AEOutput.CMD_STRING), value=text, dev=dev, 
-                       sem=sem, layer=layer)  
+    self.out_mons.show(OutputEvent(AEConstants.CMD_STRING), value=text, 
+                       dev=dev, sem=sem, layer=layer)  
     if dev is None: return
     # get the style
     style = dev.getStyle((sem, layer))
     # respect muting
     if style.Mute: return
     # parse the string using the current style
-    parsed = dev.parseString(text, style, por)
+    parsed = dev.parseString(text, style, por, sem)
     # send all words, pors, and styles
     for word, por, new_style in parsed:
-      # @todo: PP: send the index and collect the marker
-      dev.send(AEOutput.CMD_STRING, word, new_style)
-    # mark the style as clean
+      dev.send(AEConstants.CMD_STRING, word, new_style)
+      # mark the style as clean
+      new_style.makeClean()
+    # mark the style clean
     style.makeClean()
 
   def sendIndex(self, dev, value, sem, layer):
@@ -319,12 +319,11 @@ class DeviceManager(object):
     @param sem: Semantic description of the index text to send or None to 
       indicate the information is void of any known semantic
     @type sem: integer
-    @param layer: Layer on which the event occurred, one of 
-      L{Task.LAYER_FOCUS}, L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
+    @param layer: Layer on which the event occurred
     @type layer: integer
     '''
     # notify registered monitors
-    self.out_mons.show(OutputEvent(AEOutput.CMD_INDEX), dev=dev, sem=sem,
+    self.out_mons.show(OutputEvent(AEConstants.CMD_INDEX), dev=dev, sem=sem,
                        layer=layer)
     if dev is None: return
     # get the style
@@ -333,7 +332,7 @@ class DeviceManager(object):
     if style.Mute: return
     try:
       # generate a new marker on the device
-      mark = dev.send(AEOutput.CMD_INDEX, None, style)
+      mark = dev.send(AEConstants.CMD_INDEX, None, style)
     except NotImplementedError:
       # do nothing when indexing not implemented
       return
@@ -348,10 +347,10 @@ class DeviceManager(object):
       # no output available
       return
     msg = _('welcome to %s version %s, revision %s') % \
-        (LSRConstants.NAME, LSRConstants.PROG_VERSION, LSRConstants.PROG_DATE)
-    st = dev.getStyle((LSRConstants.SEM_ITEM, AEEvent.LAYER_FOCUS))
-    dev.send(AEOutput.CMD_STRING, msg, st)
-    dev.send(AEOutput.CMD_TALK, None)
+        (AEConstants.NAME, AEConstants.PROG_VERSION, AEConstants.PROG_DATE)
+    st = dev.getStyle((AEConstants.SEM_ITEM, AEConstants.LAYER_FOCUS))
+    dev.send(AEConstants.CMD_STRING, msg, st)
+    dev.send(AEConstants.CMD_TALK, None)
     
   def sendGoodbye(self):
     '''Outputs the LSR goodbye message on the default output device.'''
@@ -360,8 +359,8 @@ class DeviceManager(object):
     except IndexError:
       # no output available
       return
-    st = dev.getStyle((LSRConstants.SEM_ITEM, AEEvent.LAYER_FOCUS))
-    dev.send(AEOutput.CMD_STRING_SYNC, _('lsr exiting'), st)
+    st = dev.getStyle((AEConstants.SEM_ITEM, AEConstants.LAYER_FOCUS))
+    dev.send(AEConstants.CMD_STRING_SYNC, _('lsr exiting'), st)
 
   def _isDuplicateDevice(self, dev, output):
     '''
@@ -422,9 +421,7 @@ class DeviceManager(object):
     '''
     Unregisters the given input device. Removes this manager from
     the list of gesture listeners stored in the device.
-    
-    @todo: PP: let an ouput device save its state too?
-    
+        
     @param dev: Device to unregister
     @type dev: L{AEInput.AEInput}
     '''
@@ -451,7 +448,7 @@ class DeviceManager(object):
     '''
     try:
       # let an output device save its styles
-      dev.postCloseOutput(self.settings_manager)
+      dev.saveStyles(self.settings_manager)
     except AttributeError:
       pass
     try:
@@ -504,37 +501,40 @@ class DeviceManager(object):
 
     try:
       # try to load styles for the device
-      dev.postInitOutput(self.settings_manager)
+      dev.loadStyles(self.settings_manager)
     except KeyError:
       # or initialize new output styles
       self._initOutputStyles(dev)
+    # finally, always call postInit to let the device do more initialization
+    # after the styles are available
+    dev.postInit()
     return True
   
   def _initOutputStyles(self, dev):
     '''
-    Initializes styles for an L{AEOutput} device. Calls 
-    L{AEOutput.AEOutput.createDistinctStyles} on the device to get an initial 
-    batch of styles to use to distinguish some types of information. If that
-    method is not implemented, the exception is ignored. Future requests to
-    use styles per semantic tag will resort to making flyweights for the
+    Initializes styles for an L{AEOutput} device. Calls
+    L{AEOutput.Base.AEOutput.createDistinctStyles} on the device to get an
+    initial batch of styles to use to distinguish some types of information. If
+    that method is not implemented, the exception is ignored. Future requests
+    to use styles per semantic tag will resort to making flyweights for the
     default style on the device.
     
     @param dev: Device reference
     @type dev: L{AEOutput}
     '''
     # create styles based on the abilities of this device
-    num_layers = len(AEEvent.LAYERS_ALL)
-    num_groups = len(LSRConstants.STYLE_GROUP_ALL)
+    num_layers = len(AEConstants.LAYERS_ALL)
+    num_groups = len(AEConstants.STYLE_GROUP_ALL)
     try:
       styles = dev.createDistinctStyles(num_groups, num_layers)
     except NotImplementedError:
       return
     # create semantics, layer to styles mapping for device
-    for layer, i in enumerate(AEEvent.LAYERS_ALL):
+    for layer, i in enumerate(AEConstants.LAYERS_ALL):
       # provide a default style for a semantic of None
       s = styles[i*num_groups]
       dev.setStyle((None, layer), s)
-      for sem, grp in LSRConstants.SEMANTIC_STYLES.items():
+      for sem, grp in AEConstants.SEMANTIC_STYLES.items():
         # provide a style for (semantic, layer, device)
         s = styles[i*num_groups + (grp % num_groups)]
         dev.setStyle((sem, layer), s)
@@ -624,11 +624,9 @@ class DeviceManager(object):
     '''
     Gets the L{AEOutput} device registered with the given capabilities.
     
-    @todo: PP: optimize?
-    
     @param caps: Desired capabilities of the output device.
     @type caps: list of string
-    @return: Output device or None if not allow caps are satisfied
+    @return: Output device or None if caps could not be satisfied
     @rtype: L{AEOutput}
     '''
     for dev in self.out_devs:
@@ -649,8 +647,22 @@ class DeviceManager(object):
       if dev.getClassName() == name:
         return dev
     return None
+
+  def getInputByCaps(self, caps):
+    '''
+    Gets the L{AEInput} device registered with the given capabilities.
+    
+    @param caps: Desired capabilities of the input device.
+    @type caps: list of string
+    @return: Output device or None if caps could not be satisfied
+    @rtype: L{AEOutput}
+    '''
+    for dev in self.in_devs:
+      if set(dev.getCapabilities()).issuperset(caps):
+        return dev
+    return None
   
-  def _onGesture(self, gesture, timestamp):
+  def _onGesture(self, gesture, timestamp, **kwargs):
     '''    
     Creates an L{AEEvent} indicating the given gesture was found on a
     registered input device. When executed, the L{AEEvent} will notify the
@@ -661,17 +673,16 @@ class DeviceManager(object):
     @type gesture: L{AEInput.Gesture}
     @param timestamp: Time at which the event occurred
     @type timestamp: float
+    @param kwargs: Additional keyword arguments to pass to the L{Task}
+    @type kwargs: dictionary
     '''
-    event = AEEvent.InputGesture(gesture, timestamp)
+    event = AEEvent.InputGesture(gesture, timestamp, **kwargs)
     self.event_manager.postEvents(event)
     # notify monitors
-    self.in_mons.show(InputEvent(AEInput.CMD_GESTURE), value=gesture, 
+    self.in_mons.show(InputEvent(AEConstants.CMD_GESTURE), value=gesture, 
                       dev=gesture.getDevice())
     
   def _onIndex(self, dev, index):
-    '''
-    @todo: PP: handle index callback markers
-    '''
     pass
     # notify monitors
     #self.out_mons.show(event=OutputEvent.MARKER)
@@ -692,8 +703,7 @@ class DeviceManager(object):
     @param sem: The device semantic from which to get the style, or None to
       get the device's default style.
     @type sem: integer 
-    @param layer: Layer on which the event occurred, one of 
-      L{Task.LAYER_FOCUS}, L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
+    @param layer: Layer on which the event occurred
     @type layer: integer
     @return: the L{AEOutput.Style} for the given semantic of a device
     @rtype: L{AEOutput.Style}
@@ -732,7 +742,7 @@ class InputEvent(DeviceEvent):
     @return: Human readable name for the command
     @rtype: string
     '''
-    return AEInput.COMMAND_NAMES[self.cmd]
+    return AEConstants.INPUT_COMMAND_NAMES[self.cmd]
   
 class OutputEvent(DeviceEvent):
   '''Event on an output device, wrapped for display by a L{AEMonitor}.'''
@@ -741,4 +751,4 @@ class OutputEvent(DeviceEvent):
     @return: Human readable name for the command
     @rtype: string
     '''
-    return AEOutput.COMMAND_NAMES[self.cmd]
+    return AEConstants.OUTPUT_COMMAND_NAMES[self.cmd]
