@@ -66,8 +66,6 @@ class GSpeechStyle(AEOutput.AudioStyle):
       cap_name = param.name.title()
       val = sp.getParameterValue(param.name)
       if param.enumerated:
-        # @todo: PP: want to factor this out so subclasses can handle 
-        # specific enumerations, otherwise value labels are unknown
         pass
       else:
         # new relative range setting
@@ -207,8 +205,6 @@ class GSpeech(AEOutput.Audio):
     @note: gnome-speech returns a negative value when there is a backlog of 
       events that must be processed by a GNOME.Speech.SpeechCallback before
       say will succeed
-    @todo: PP: store the return value of say to correlate callback markers
-    @todo: PP: kludge converting to latin-1 for now, fix when language is known
     @param text: Text to say
     @type text: string
     '''
