@@ -14,7 +14,7 @@ this distribution, and is available at
 U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 import logging, weakref, os, sys
-import Task, AEInput, AEEvent, LSRInterfaces, UIElement, AEConstants
+import Task, AEInput, AEEvent, AEInterfaces, UIElement, AEConstants
 from i18n import _
 from AEState import AEState as PerkState
 
@@ -234,7 +234,7 @@ class Perk(Task.Tools.All, UIElement.UIE):
                           wtask, weman)
     self.tier.addTaskRef(tid, self)
   
-  def registerCommandTask(self, device, codes, name, propogate=False):
+  def registerCommandTask(self, device, codes, name, propagate=False):
     '''
     Registers a L{Task} in this L{Tier} to be executed in response to an 
     L{AEEvent} indicating that the given action codes were input on the given 
@@ -250,9 +250,9 @@ class Perk(Task.Tools.All, UIElement.UIE):
     @param name: Name of the L{Task} registered via L{registerNamedTask} to 
       execute when the input gesture is detected on the device
     @type name: string
-    @param propogate: Should the input gesture be allowed to propogate to the
+    @param propagate: Should the input gesture be allowed to propagate to the
       OS after we receive it?
-    @type propogate: boolean
+    @type propagate: boolean
     @raise ValueError: When a L{Task} with the given name is not registered
     '''
     # construct the key list and find the Task with the given name
@@ -267,7 +267,7 @@ class Perk(Task.Tools.All, UIElement.UIE):
     # as its value
     self.commands[gl] = name
     self.tier.addTaskRef(gl, self)
-    if not propogate:
+    if not propagate:
       # try to add a filter to the device, ignore if not supported
       try:
         device.addFilter(gl)
@@ -412,8 +412,8 @@ class Perk(Task.Tools.All, UIElement.UIE):
     @type codes:  list of list of integer
     @raise KeyError: When a L{AEInput.GestureList} is not registered
     '''
-    # GestureList has __eq__ and __hash__ overridden so two different instances 
-    # can hash to the same dictionary location as long as their devices and 
+    # GestureList has __eq__ and __hash__ overridden so two different instances
+    # can hash to the same dictionary location as long as their devices and
     # codes are the same
     gl = AEInput.GestureList(device, codes)
     del self.commands[gl]
@@ -589,8 +589,8 @@ class Perk(Task.Tools.All, UIElement.UIE):
     @type target: string
     @param link: One of the CHAIN constants in L{AEConstants.Tools} 
     @type link: integer
-    @raise KeyError: When there is no segment for the given target and link
-      type
+    @return: L{Task} names chained in the given manner
+    @rtype: list of string
     '''
     if link == AEConstants.CHAIN_BEFORE:
       return self.before_chains.get(target, [])[:]
@@ -601,6 +601,29 @@ class Perk(Task.Tools.All, UIElement.UIE):
       if self.around_chains.has_key(target):
         alist.append(self.around_chains[target])
       return alist
+    
+  def mergeChain(self, target, before, after):
+    '''
+    Adds the before and after segments of the chain for the target specified.
+    The parameters before and after are lists, possibly containing segments 
+    from other L{Perk}s. These lists are modified in place for performance.
+    The around segment is returned since it is a single value.
+
+    @param target: Name of the L{Task} to link to
+    @type target: string
+    @return: L{Task} name for around link type, or None if nothing is linked
+      around the target
+    @rtype: string
+    '''
+    try:
+      before.extend(self.before_chains[target])
+    except KeyError:
+      pass
+    try:
+      after.extend(self.after_chains[target])
+    except KeyError:
+      pass
+    return self.around_chains.get(target, None)
   
   def linkTaskToChain(self, name, link, target):
     '''
