@@ -7,25 +7,23 @@ from disk.
 
 @author: Peter Parente
 @organization: IBM Corporation
-@copyright: Copyright (c) 2006 IBM Corporation
-@license: Common Public License 1.0
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
-from LSRConstants import HOME_USER, BUILTIN_PROFILES
+from AEConstants import HOME_USER, BUILTIN_PROFILES, initUserPath
 from i18n import _
-import shelve, os, shutil
+import shelve, os, shutil, whichdb
 
 # paths to parts of the settings repository
 PROFILES_PATH = os.path.join(HOME_USER, 'profiles')
 # make sure the profile folder is available
-try:
-  os.makedirs(PROFILES_PATH)
-except OSError:
-  pass
+if initUserPath(PROFILES_PATH):
+  print 'created ~/.lsr/profiles'
 
 class SettingsManager(object):
   '''
@@ -70,7 +68,7 @@ class SettingsManager(object):
     for name, state in self.cache.items():
       self.saveState(name, state)
       
-  def loadStyles(self, name, default_style, flyweight_style_cls):
+  def loadStyles(self, device, default_style, style_cls):
     '''
     Loads a collection of L{AEOutput.Style} objects from disk. The loaded 
     styles are not stored in the L{cache} as the singleton requirement does
@@ -78,41 +76,47 @@ class SettingsManager(object):
     not be automatically persisted when this object is destroyed. L{saveStyles}
     should be invoked directly.
     
+    @param device: Output device whose style objects we're loading
+    @type device: L{AEOutput}
     @param default_style: Instance of a default style object to be populated
       with data
-    @type default_style: L{AEOutput.Style.StyleDefault}
-    @param flyweight_style_cls: Class for a flyweight styles to be instantiated 
-    @type flyweight_style_cls: L{AEOutput.Style.StyleFlyweight} class
+    @type default_style: L{AEOutput.Style.Style}
+    @param style_cls: Class for constructing new styles to populate
+    @type style_cls: L{AEOutput.Style.Style} class
     @raise KeyError: When the name is not a valid key
     @raise OSError: When the profile file cannot be opened or read
     '''
-    default_data, styles_data = self.load(name)
+    default_data, styles_data = self.load(device.getClassName())
     # get the default style first
-    default_style.setState(default_data)
+    default_style.unserialize(default_data)
     flyweight_styles = {}
     for key, data in styles_data:
       # build flyweights ontop of the default style
-      st = flyweight_style_cls(default_style)
-      st.setState(data)
+      st = style_cls(default_style)
+      st.init(device)
+      st.unserialize(data)
       flyweight_styles[key] = st
     return flyweight_styles
   
-  def saveStyles(self, name, default_style, flyweight_styles):
+  def saveStyles(self, device, default_style, other_styles):
     '''
     Saves the internal data of a collection L{AEOutput.Style} objects to disk.
     
+    @param device: Output device whose style objects we're persisting
+    @type device: L{AEOutput}
     @param default_style: Instance of a default style object to have its data
       persisted
-    @type default_style: L{AEOutput.Style.StyleDefault}
-    @param flyweight_styles: Dictionary of flyweight styles to have their data
-      persisted
-    @type flyweight_styles: dictionary of immutable : 
-      L{AEOutput.Style.StyleFlyweight}
+    @type default_style: L{AEOutput.Style.Style}
+    @param other_styles: Dictionary of other styles to have their data 
+      persisted under the keys used in the dictionary
+    @type other_styles: dictionary of immutable : 
+      L{AEOutput.Style.Style}
     @raise OSError: When the profile file cannot be opened or saved
     '''
-    flyweight_data = [(key, style.getState()) for key, style in 
-                      flyweight_styles.items()]
-    self.save(name, (default_style.getState(), flyweight_data))
+    flyweight_data = [(key, style.serialize()) for key, style in 
+                      other_styles.items()]
+    self.save(device.getClassName(), 
+              (default_style.serialize(), flyweight_data))
   
   def loadState(self, name, state):
     '''
@@ -139,17 +143,17 @@ class SettingsManager(object):
     # try to load data for the state object
     data = self.load(name)
     # wrap the data in the state object
-    state.setState(data)
+    state.unserialize(data)
     return state
   
   def saveState(self, name, state):
     '''
     Saves the internal data of an L{AEState} object to disk. Does not Pickle
-    the state object directly, but rather calls its getState method to get a
+    the state object directly, but rather calls its serialize method to get a
     simple dictionary. This is done to avoid the problems caused by trying to
     persist state objects in modules that have been reloaded at runtime. Also
     does not Pickle states that are not dirty according to 
-    L{AEState.AEState.isDirty}.
+    L{AEState.Base.AEState.isDirty}.
     
     @param name: Name under which to save the object
     @type name: string
@@ -158,7 +162,7 @@ class SettingsManager(object):
     @raise OSError: When the profile file cannot be opened or saved
     '''
     if state.isDirty():
-      self.save(name, state.getState())
+      self.save(name, state.serialize())
     
   def save(self, name, data):
     '''    
@@ -220,7 +224,7 @@ class SettingsManager(object):
     @return: Does the managed profile exist on disk?
     @rtype: boolean
     '''
-    return os.path.exists(self.profile)
+    return whichdb.whichdb(self.profile) is not None
   
   def deleteProfile(self):
     '''
