@@ -4,29 +4,29 @@ Defines a Task to execute when the focus changes.
 @author: Peter Parente
 @author: Pete Brunet
 @organization: IBM Corporation
-@copyright: Copyright (c) 2005, 2006 IBM Corporation
-@license: Common Public License 1.0
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
+@license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
-available under the terms of the Common Public License v1.0 which accompanies
+available under the terms of the BSD license which accompanies
 this distribution, and is available at
-U{http://www.opensource.org/licenses/cpl1.0.php}
+U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
-import EventTask, Constants
+import Base, EventTask
 import AEEvent
 
 class FocusTask(EventTask.EventTask):
   '''
   Executed when a focus change occurs. 
-
-  This class registers its name and whether it should be monitored by default in
-  an L{AEMonitor} using the L{Constants.registerTaskType} function
-  when this module is first imported. The L{AEMonitor} can use this
-  information to build its menus.
+  
+  This class registers its name and whether it should be monitored by default
+  in an L{AEMonitor} using the L{Base.registerTaskType} function when this
+  module is first imported. The L{AEMonitor} can use this information to build
+  its menus.
   '''
-  Constants.registerTaskType('FocusTask', True)
-
+  Base.registerTaskType('FocusTask', True)
+  
   def getEventType(self):
     '''
     @return: Type of L{AEEvent} this L{Task} wants to handle
@@ -43,8 +43,7 @@ class FocusTask(EventTask.EventTask):
     @type por: L{POR}
     @param gained: Was focus gained (True) or lost (False)
     @type gained: boolean
-    @param layer: Layer on which the event occurred, one of L{Task.LAYER_FOCUS},
-      L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
+    @param layer: Layer on which the event occurred
     @type layer: integer
     '''
     pass
@@ -58,8 +57,7 @@ class FocusTask(EventTask.EventTask):
     @type por: L{POR}
     @param gained: Was focus gained (True) or lost (False)
     @type gained: boolean
-    @param layer: Layer on which the event occurred, one of L{Task.LAYER_FOCUS},
-      L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
+    @param layer: Layer on which the event occurred
     @type layer: integer
     @return: True to allow other L{Task}s to process this event
     @rtype: boolean
@@ -76,8 +74,7 @@ class FocusTask(EventTask.EventTask):
     
     @param por: Focused point of regard
     @type por: L{POR}
-    @param layer: Layer on which the event occurred, one of L{Task.LAYER_FOCUS},
-      L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
+    @param layer: Layer on which the event occurred
     @type layer: integer
     @return: True to allow other L{Task}s to process this event
     @rtype: boolean
@@ -91,8 +88,7 @@ class FocusTask(EventTask.EventTask):
     
     @param por: Unfocused point of regard
     @type por: L{POR}
-    @param layer: Layer on which the event occurred, one of L{Task.LAYER_FOCUS},
-      L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
+    @param layer: Layer on which the event occurred
     @type layer: integer
     @return: True to allow other L{Task}s to process this event
     @rtype: boolean
