@@ -566,7 +566,7 @@ class System(Base.TaskTools):
       # first try as an event task
       self.perk.registerEventTask(task, *task.getEventLayers())
       count += 1
-    except AttributeError:
+    except (AttributeError, NotImplementedError):
       pass
     try:
       # then try as a timer task
@@ -624,12 +624,11 @@ class System(Base.TaskTools):
     
   def chainTask(self, name, link, target):
     '''
-    Chains the L{Task} with the given name to the target L{Task}. If
-    link is L{AEConstants.CHAIN_BEFORE}, the linked L{Task} will execute before
-    the target. If link is L{AEConstants.CHAIN_AFTER}, the linked L{Task} will
-    execute after. If link is L{AEConstants.CHAIN_AROUND}, the linked L{Task}
-    will execute in lieu of the target, but can execute the target manually
-    using L{doTask}.
+    Chains the L{Task} with the given name to the target L{Task}. If link is
+    CHAIN_BEFORE, the linked L{Task} will execute before the target. If link is
+    CHAIN_AFTER, the linked L{Task} will execute after. If link is
+    CHAIN_AROUND, the linked L{Task} will execute in lieu of the target, but
+    can execute the target manually using L{doTask}.
     
     @param target: Name of the L{Task} to link to
     @type target: string
@@ -729,9 +728,6 @@ class System(Base.TaskTools):
     Gets the default L{AEState} associated with an L{AEOutput} or L{AEInput} 
     device currently loaded in the L{DeviceManager}.
     
-    @todo: PP: currently coded to support output devices only and then only
-      their default styles
-    
     @param device_name: Name of the device
     @type device_name: string
     @return: Loaded state for the device
@@ -896,7 +892,7 @@ class System(Base.TaskTools):
     (False), or if all other L{Task}s chained to it are as well (True). The
     propagate parameter determines whether the execute or update method is
     called on the L{Task}. This param is not typically specified by a L{Task}
-    or L{Perk}. It is used internally by L{Task.CyclicTask} to handle the
+    or L{Perk}. It is used internally by L{Task.CyclicInputTask} to handle the
     propagation flag in Task chains.
     
     @param task_name: Name of the L{Task} to execute
@@ -917,10 +913,15 @@ class System(Base.TaskTools):
     '''
     # use the current layer if one is not specified
     if layer is None: layer = self.layer
-    self.tier.manageNamedTask(self.task_por, task_name, layer, kwargs,
-                              chain=chain)
-    self.task_por = self.getPointerPOR()
-    
+    # make sure a Task exists with the given name
+    task = self.tier.getNamedTask(task_name)
+    if task is not None:
+      perk = task.getPerk()
+      self.tier.manageChain(self.task_por, task_name, task, perk, layer, 
+                            kwargs, propagate, chain)
+    # use the pointer as the new task por
+    self.task_por = self.tier.getPointer()
+
   def blockNTasks(self, n, task_type, condition=lambda **x: True):
     '''
     Blocks L{Task}s of the given type from executing in response to the next
@@ -954,8 +955,6 @@ class System(Base.TaskTools):
     '''
     Associates a L{Perk} with the active profile.
     
-    @todo: PP: push instances of this Perk onto appropriate tiers?
-    
     @param name: Name of the UIE to associate
     @type name: string
     @param tier: Name of the L{Tier} with which the L{Perk} will be associated.
@@ -974,8 +973,6 @@ class System(Base.TaskTools):
     '''
     Disassociates a L{Perk} from the active profile.
     
-    @todo: PP: remove currently loaded instances of this Perk?
-    
     @param name: Name of the UIE to disassociate
     @type name: string
     @param tier: Name of the L{Tier} from which the L{Perk} will be 
@@ -1203,9 +1200,9 @@ class System(Base.TaskTools):
     @type perk_name: immutable
     @param setting_name: Name of the perk
     @type setting_name: immutable
-    @value: value contained in L{AEState} attribute with given name
-    @value: object
-    @raise KeyError:  When the perk is not found
+    @param value: value contained in L{AEState} attribute with given name
+    @param value: object
+    @raise KeyError:  When the L{Perk} is not found
     '''
     if perk_name is None:
       perk_name = self.perk.getClassName()
