@@ -38,7 +38,7 @@ class Utils(Base.TaskTools):
     except (ValueError, TypeError, AttributeError):
       return val
     WORD = 256 # 8-bit word size
-    # @todo: DBC: tweak these values
+    
     VISIBLE = 64
     LOW_COLORATION = 4 
     LOW_SATURATION = 192
@@ -53,11 +53,9 @@ class Utils(Base.TaskTools):
     # if all values of RGB 3-tuple have low saturation, amplify them
     while r < VISIBLE and g < VISIBLE and b < VISIBLE and \
           (r > LOW_COLORATION or g > LOW_COLORATION or b > LOW_COLORATION):
-      print "low saturation: shifting rgb from:", r, g, b
       r = r << 1
       g = g << 1
       b = b << 1
-      print "shifted rgb to:" , r, g, b
       
     # attenuation algo #1  
     ## if all values of RGB 3-tuple have high saturation, attenuate them
@@ -73,7 +71,6 @@ class Utils(Base.TaskTools):
     # if all values of RGB 3-tuple have high saturation, attenuate them
     if r >= LOW_SATURATION and g >= LOW_SATURATION and b >= LOW_SATURATION and \
        (r < HIGH_SATURATION or g < HIGH_SATURATION or b < HIGH_SATURATION):
-      print "high saturation: shifting rgb from:", r, g, b
       if r < g and r < b:
         r = r - 64
       elif g < r and g < b:
@@ -100,7 +97,6 @@ class Utils(Base.TaskTools):
       elif g == b:
         g = g - 64
         b = b - 64
-      print "shifted rgb to:" , r, g, b
       
     # place high 2-bits of each color into bitfield: rrggbb for value 0..63
     r = r >> 6 << 4
@@ -110,4 +106,41 @@ class Utils(Base.TaskTools):
     name = AEConstants.COLOR_MAP[rgb] # get the color value from dictionary
     return name
   
- 
\ No newline at end of file
+  def convertPOSIXToIANA(self, lang):
+    '''
+    Converts a POSIX language string to a IANA language tag following RFC 4646
+    U{http://www.ietf.org/rfc/rfc4646.txt}, the format recommended for 
+    L{AEOutput} device language settings.
+    
+    The POSIX format is language[_territory][.codeset]
+    
+    Some examples include "en", "fr_CA", "en_US.UTF-8". Ambiguous conversions 
+    such as "zh_CN" are allowed, but do not pinpoint specific spoken dialects 
+    (i.e. Mandarin, Cantonese, Pinyin, Taiwanese Mandarin, etc.) The code set
+    is currently ignored, though may serve as a hint for the dialect in the
+    future.
+
+    @param lang: POSIX locale string
+    @type lang: string
+    @return: IANA language tag
+    @rtype: string
+    '''
+    tag = []
+    lang = lang.split('_')
+    try:
+      # if first element is there, it's the language code
+      tag.append(lang[0])
+    except IndexError:
+      pass
+    try:
+      # if the second element is there, it's the territory code
+      t = lang[1].split('.')[0]
+    except IndexError:
+      pass
+    else:
+      # if there was no language code, backfill using the territory
+      if len(tag) == 0:
+        tag.append(t)
+      tag.append(t) 
+    # make lowercase for comparison
+    return '-'.join(tag).lower()
