@@ -8,7 +8,7 @@ raise.
 @author: Pete Brunet
 @author: Brett Clippingdale
 @organization: IBM Corporation
-@copyright: Copyright (c) 2005, 2006 IBM Corporation
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
 @license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
@@ -16,10 +16,8 @@ available under the terms of the BSD license which accompanies
 this distribution, and is available at
 U{http://www.opensource.org/licenses/bsd-license.php}
 '''
-
-import Constants
 from Tools.Error import *
-from Base import Task
+from Base import *
 from ChooserTask import ChooserTask
 from FocusTask import FocusTask
 from ViewTask import ViewTask
@@ -34,27 +32,3 @@ from TableTask import TableTask
 from TimerTask import TimerTask
 from ScreenTask import ScreenTask
 from MouseTask import MouseTask
-from SettingTask import SettingTask
-
-# import constants from AEEvent indicating the layer for the event
-from Constants import LAYER_FOCUS, LAYER_TIER, LAYER_BACKGROUND
-
-def getDefaults():
-  '''
-  Suggests the default L{Task}s to be monitored. Reads the 
-  
-  @return: Names of defaults to monitor
-  @rtype: list of string
-  '''
-  return Constants.default_types  
-  
-def getNames():
-  '''
-  Gets the names of all the L{Task} types.
-  
-  @return: List of all L{Task} names
-  @rtype: list of string
-  '''
-  names = Constants.all_types
-  names.sort()
-  return names
\ No newline at end of file
