@@ -24,7 +24,7 @@ import logging
 import pyLinAcc
 from AEEvent import *
 from POR import POR
-from LSRInterfaces import *
+from AEInterfaces import *
 from Walker import AccessibleWalker
 
 log = logging.getLogger('View')
@@ -41,8 +41,8 @@ class ViewManager(object):
   Stores a root accessible representing the active view when an event occurs
   indicating that the view may have changed. Two view roots must be tracked
   by this object. The first, the raw view, is needed by L{Adapters} which will
-  handle raw view change events. The second, the L{AcessEngine} view, is needed
-  by the rest of the system when processing L{AEEvent}s.
+  handle raw view change events. The second, the L{AccessEngine} view, is 
+  needed by the rest of the system when processing L{AEEvent}s.
   
   @ivar event_manager: Reference to the L{EventManager}
   @type event_manager: L{EventManager}
@@ -112,10 +112,14 @@ class ViewManager(object):
     that application, creates a L{Tier} for the application and loads all of
     its L{Perk}s. If the L{Tier} is created, this method sends
     L{AEEvent.ViewChange} messages to the L{Tier} with a flag of
-    L{AEConstants.EVENT_VIEW_STARTUP} such that L{Perk}s in the L{Tier}
+    L{AEConstants.Event.EVENT_VIEW_STARTUP} such that L{Perk}s in the L{Tier}
     may initialize themselves and begin any desired background processes.
     '''
-    d = pyLinAcc.Registry.getDesktop(0)
+    try:
+      d = pyLinAcc.Registry.getDesktop(0)
+    except Exception:
+      # just stop if we get an error right away
+      return
     ai = IAccessibleInfo(POR(d))
     an = IAccessibleNav(POR(d))
     events = []
@@ -202,7 +206,7 @@ class ViewManager(object):
   def getRawView(self):
     '''
     Gets the root L{POR} of the active view according to the raw event
-    stream. This is the view known to L{Adapter}s.
+    stream. This is the view known to L{Adapters}.
     
     @see: L{setRawView}
     @return: Root L{POR} of the raw active view
@@ -213,7 +217,7 @@ class ViewManager(object):
   def setRawView(self, accessible):
     '''    
     Stores the root L{POR} of the active view according to the raw event 
-    stream. This is the view known to L{Adapter}s.
+    stream. This is the view known to L{Adapters}.
     
     @see: L{getRawView}
     @param accessible: Event source that triggered the change of view. Usually
@@ -245,8 +249,8 @@ class ViewManager(object):
   
   def setAEView(self, por):
     '''
-    Stores the root L{POR} of the active view according to the L{AEEvent 
-    stream. This is the view known to L{Adapter}s.
+    Stores the root L{POR} of the active view according to the L{AEEvent}
+    stream. This is the view known to L{Adapters}.
     
     @see: L{getAEView}
     @param por: New root L{POR} of the active L{AccessEngine} view. May be
@@ -264,7 +268,11 @@ class ViewManager(object):
     @return: True to continue receiving notifications
     @rtype: boolean
     '''
-    d = pyLinAcc.Registry.getDesktop(0)
+    try:
+      d = pyLinAcc.Registry.getDesktop(0)
+    except Exception:
+      # stop if we get an error immediately
+      return
     ai = IAccessibleInfo(POR(d))
     an = IAccessibleNav(POR(d))
     aids = []
@@ -291,20 +299,28 @@ class ViewManager(object):
     '''
     # only forward events if there is a view
     if self.raw_view is not None:
-      eh = IEventHandler(event.source)
-      eh.getAEEvents(event, self.event_manager.postEvents)
+      try:
+        eh = IEventHandler(event.source)
+        eh.getAEEvents(event, self.event_manager.postEvents)
+      except LookupError:
+        # ignore dead accessibles
+        return
     
   def onRawViewEvent(self, event):
     '''   
     Creates a L{AEEvent.ViewChange} event in response to a window activation or
     deactivation. Also responds to create or destroy events from floating
     windows. Called in response to any of the raw events returned by
-    L{LSRInterfaces.IEventHandler.getAEViewEvents} and registered with the
+    L{AEInterfaces.IEventHandler.getAEViewEvents} and registered with the
     L{EventManager} in the L{ViewManager.init} method when this object was
     created.
 
     @param event: Event that may indicate the view has changed
     @type event: L{pyLinAcc.Event.Event}
     '''
-    eh = IEventHandler(event.source)
-    eh.getAEViewEvents(event, self.event_manager.postEvents, self)
\ No newline at end of file
+    try:
+      eh = IEventHandler(event.source)
+      eh.getAEViewEvents(event, self.event_manager.postEvents, self)
+    except LookupError:
+      # ignore dead accessibles
+      return
