@@ -16,7 +16,7 @@ U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
 import Base
-from LSRInterfaces import *
+from AEInterfaces import *
 
 class AccessibleItemWalker(Base.Walker):
   '''  
@@ -25,7 +25,7 @@ class AccessibleItemWalker(Base.Walker):
   accessible hierarchy rooted at a top-level window accessible. The subtree is
   assumed to have no loops, though logic could be added to detect them. The
   supported flags determine whether invisible or trivial items are skipped or
-  not. This class uses the L{LSRInterfaces} to leave the decision of what
+  not. This class uses the L{AEInterfaces} to leave the decision of what
   constitutes an item, what constitutes a trivial accessible, and what
   constitutes and invisible accessible to the objects that implement the
   interfaces.
@@ -405,7 +405,7 @@ class AccessibleItemWalker(Base.Walker):
       por, state = state(por)
     if por is not None:
       self.por = por
-    #print por
+    #print 'STOP prev', por
     return por
   
   def getFirstPOR(self):
