@@ -42,7 +42,7 @@ class WordState(AEState.AEState):
 
   Caps (bool): When set to True, capitalization is preserved when presenting
   text. Defaults to True.
- 
+
   MaxRepeat (integer): Specifies the minimum number of times a character must 
   be found in sequence before it is considered a repeat. Defaults to 4.
 
@@ -54,8 +54,8 @@ class WordState(AEState.AEState):
   to only include characters that are alphabetic, numeric, or punctuation.
   Defaults to NON_BLANK.
 
-    Ignore (string): Set to a string of characters that should be treated as if 
-  they were blank. Defaults to an empty string.
+  Ignore (string): Set to a string of characters that should be treated as if 
+  they were blank. Defaults to the NBSP character.
   '''
   def __init__(self):
     '''
@@ -82,7 +82,7 @@ class WordState(AEState.AEState):
                   _('Alpha and punct.') : WORD_ALPHA_PUNCT,
                   _('Alphabetic') : WORD_ALPHABETIC},
                  _('Defines the characters that comprise a word.'))
-    self.newString('Ignore', '', _('Ignored characters'), 
+    self.newString('Ignore', u'\u00a0', _('Ignored characters'), 
                    _('Defines the characters to be treated as blanks.'))
 
 class DefaultWordState(object):
@@ -94,7 +94,7 @@ class DefaultWordState(object):
   Caps = True
   MaxRepeat = 4
   WordDef = WORD_NON_BLANK
-  Ignore = ''
+  Ignore = u'\u00a0'
 
 def getContextFromString(string, por, state=DefaultWordState):
   '''  
@@ -699,6 +699,8 @@ class Word(object):
     @rtype: string
     '''
     self.source_word.append(ch)
+    if ch in self.state.Ignore:
+      ch = u' '
     if not self.state.Caps:
       ch = ch.lower()
     if self.main_ob:
@@ -716,6 +718,8 @@ class Word(object):
     @return: Character inserted in L{trail_part}
     @rtype: string
     '''
+    if ch in self.state.Ignore:
+      ch = u' '
     self.source_word.append(ch)
     if self.trail_ob:
       ch = self.trail_ob(self, self.state, ch, self.trail_part)
